==> gytrash-0.0.2.tar.gz: gytrash-0.0.2/gytrash/__about__.py <==
ascii_chartis_logo = """
                                                .##,
                                               /####(.
                                              /########/.
                                              ###########(.
                                             /##############(,
                                            ,#################(*
                                           .######################,
                                           (########################/.
                                          /############################/.
                                          ###############################(.
                                         /##################################(,
                                        ,#####################################(*
                                       .##########################################,
                                       (############################################/.
                                      /################################################/
                                      ###################################################(.
                                     /######################################################(,
                                    ,#########################################################(*
                                   .##############################################################,
                                   (################################################################/.
                                  /######################%&&%##########################################/
                                  #####################%&&&%%%###########################################(.
                                 /##################%&&&&&%%%%##############################################(,
                                ,################%&&&&&&&&%%%%%###############################################(*
                               .##############%%%%&&&&&@@%%%%%%%##################################################,
                               (############%%%%%%%%%&&@&%%%%%%%####################################################/.
                              /##########%%%%%%%%%%%%%%%%%%%%%%%%######################################################/
                              ########%%%%%%%%%%%%%%%%%%%%%%%%%%%%#######################################################(.
                             /#####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%##########################################################(,
                            ,####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###########################################################(,
                           .##%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###############################################################,
                           ,#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/,..................,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,.
                              ./#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/
                                 .(%%%%%%%%%%%%%%%%%%%%%%%%%%(.
                                     ,#%%%%%%%%%%%%%%%%%%#*
                                        *#%%%%%%%%%%%%%(.
                                           ,(%%%%%%#/.
                                              *#%#.
"""

__title__ = "gytrash"
version = "0.0.2"
__description__ = "Useful things for Logging."
__url__ = "http://github.com/trejas/gytrash"
__author__ = "Trey Hatch"
__author_email__ = "trey@newmathdata.com"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2020 New Math Data"

==> gytrash-0.0.8.tar.gz: gytrash-0.0.8/gytrash/__about__.py <==
ascii_chartis_logo = """
                                                .##,
                                               /####(.
                                              /########/.
                                              ###########(.
                                             /##############(,
                                            ,#################(*
                                           .######################,
                                           (########################/.
                                          /############################/.
                                          ###############################(.
                                         /##################################(,
                                        ,#####################################(*
                                       .##########################################,
                                       (############################################/.
                                      /################################################/
                                      ###################################################(.
                                     /######################################################(,
                                    ,#########################################################(*
                                   .##############################################################,
                                   (################################################################/.
                                  /######################%&&%##########################################/
                                  #####################%&&&%%%###########################################(.
                                 /##################%&&&&&%%%%##############################################(,
                                ,################%&&&&&&&&%%%%%###############################################(*
                               .##############%%%%&&&&&@@%%%%%%%##################################################,
                               (############%%%%%%%%%&&@&%%%%%%%####################################################/.
                              /##########%%%%%%%%%%%%%%%%%%%%%%%%######################################################/
                              ########%%%%%%%%%%%%%%%%%%%%%%%%%%%%#######################################################(.
                             /#####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%##########################################################(,
                            ,####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###########################################################(,
                           .##%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###############################################################,
                           ,#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/,..................,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,.
                              ./#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/
                                 .(%%%%%%%%%%%%%%%%%%%%%%%%%%(.
                                     ,#%%%%%%%%%%%%%%%%%%#*
                                        *#%%%%%%%%%%%%%(.
                                           ,(%%%%%%#/.
                                              *#%#.
"""

__title__ = "gytrash"
__description__ = "Useful things for Logging."
__url__ = "http://github.com/trejas/gytrash"
__author__ = "Traey Hatch"
__author_email__ = "thatch@newmathdata.com"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2020 New Math Data"
